pub trait ErrorKind:
Debug
+ Display
+ Copy {
const OTHER: Self;
// Required method
fn uncategorized() -> Self;
}Expand description
Base trait for the kind of Errors.
Error Kinds are simple types (usually flat enums) that describes the overall category of an error (with the payload being encoded in the Error type instead).
Because ErrorKind implementors are simple, they are expected to implement Copy, as well as Debug and Display.
Required Associated Constants
Required Methods
Sourcefn uncategorized() -> Self
fn uncategorized() -> Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".