#[non_exhaustive]pub enum OsError {
Show 55 variants
Other,
PermissionDenied,
NotFound,
NoSuchProcess,
Interrupted,
InputOutputError,
TooBig,
ExecFormatError,
InvalidHandle,
NoChild,
WouldBlock,
NoMemory,
InvalidMemory,
WrongDeviceKind,
Busy,
ObjectExists,
CrossDevice,
NoSuchDevice,
NotADirectory,
IsADirectory,
InvalidArgument,
GlobalHandleExhaustion,
HandleExhaustion,
Ioctl,
TextFileBusy,
NoSpaceLeft,
InvalidSeek,
ReadOnlyFilesystem,
TooManyLinks,
SymbolicLinkChain,
BrokenPipe,
DomainError,
RangeError,
Deadlock,
ResourceExhaustion,
UnsupportedSystemOp,
ConnectionRefused,
ConnectionReset,
InvalidFilename,
InProgress,
QuotaExceeded,
HostUnreachable,
NetworkUnreachable,
ConnectionAborted,
NotConnected,
AddrInUse,
AddrNotAvailable,
NetworkDown,
InvalidData,
TimedOut,
StaleNetworkFileHandle,
DirectoryNotEmpty,
UnexpectedEof,
WriteZero,
AlreadyInProgress,
}Expand description
Variant for encoding most os errors as a generic enum that can be matched upon in code - suitable for implementing FromRawOsError
OsError itself implements ErrorKind and FromRawOsError. However, it does not implement or IntoIoKind
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Other
Other errors not generated. Note that this is not produced by the impl for FromRawOsError
PermissionDenied
Permission Denied
NotFound
An Object was not found
NoSuchProcess
A Process was not found
Interrupted
System Call interrupted by signal/remote action
InputOutputError
Input/Output Error
TooBig
A name, a record, or list was too large for a system call
ExecFormatError
An process being spawned refers to an executable file that cannot be read
InvalidHandle
A Handle or File Descriptor is invalid/wrong type
NoChild
A Child process was not found
WouldBlock
An operation that was required not to block would have blocked
NoMemory
Memory is unavailable or cannot be allocated
InvalidMemory
A memory address passed to a system call was invalid/not mapped
WrongDeviceKind
A different kind of device was required
Busy
An Object being accessed was Busy
ObjectExists
An object that was required not to exist was located
CrossDevice
An operation crosses devices when it is required not to
NoSuchDevice
A device being identified does not exist
NotADirectory
An object being used as a directory was not a directory
IsADirectory
An object that is required not to be a directory was a directory
InvalidArgument
Invalid Argument/Operation
GlobalHandleExhaustion
A Global Handle Limit was exceeded
HandleExhaustion
A Local Handle Limit was exceeded
Ioctl
Invalid extended operation
TextFileBusy
An executable file is busy
NoSpaceLeft
No Space Left on Device
InvalidSeek
Seek on Non-Seekable Object
ReadOnlyFilesystem
Read-Only Filesystem
TooManyLinks
Too many links to the same object
SymbolicLinkChain
Symbolic Link Loop or excessive symbolic link chain
BrokenPipe
Broken Pipe
DomainError
Domain Error
RangeError
Range Error
Deadlock
Deadlock (Avoided)
ResourceExhaustion
A resource other than handle count, is exhausted
UnsupportedSystemOp
Unsupported System Call
ConnectionRefused
Connection Refused
ConnectionReset
Connection Reset
InvalidFilename
Invalid Filename
InProgress
Operation In-progress
QuotaExceeded
Quota Exceeded
HostUnreachable
Destination Host Unreachable
NetworkUnreachable
Destination Network Unreachable
ConnectionAborted
Connection Aborted
NotConnected
Socket not connected
AddrInUse
Bind address in use
AddrNotAvailable
Bind address not available
NetworkDown
Network down
InvalidData
Invalid Data
TimedOut
Operation timed out
StaleNetworkFileHandle
Stale File handle
DirectoryNotEmpty
Directory not empty
UnexpectedEof
Unexpected Eof
WriteZero
Write returned zero
AlreadyInProgress
Operation Already In progress